<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ka">
<context>
    <name>KvantumPreviewBase</name>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="14"/>
        <source>Kvantum Preview</source>
        <translation>წინასწარი გადახედვა Kvantum</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="29"/>
        <source>Push buttons</source>
        <translation>ღილაკები</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="77"/>
        <source>Toggle
push
button

with
height
greater
than
width</source>
        <translation>დასაწოლი
ღილაკის
გადართვა

უფრო
დიდი
სიმაღლით
ვიდრე
სიგანით</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="95"/>
        <location filename="../../KvantumPreviewBase.ui" line="105"/>
        <source>Simple push button</source>
        <translation>უბრალო ღილაკი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="112"/>
        <location filename="../../KvantumPreviewBase.ui" line="128"/>
        <source>Toggle push button</source>
        <translation>გადამრთველი ღილაკი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="141"/>
        <location filename="../../KvantumPreviewBase.ui" line="152"/>
        <source>Multi-line
 push button</source>
        <translation>მრავალხაზიანი
ღილაკი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="160"/>
        <location filename="../../KvantumPreviewBase.ui" line="180"/>
        <source>Push button
with 32px folder icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="210"/>
        <location filename="../../KvantumPreviewBase.ui" line="224"/>
        <source>Default
push button</source>
        <translation>ნაგულისხმევი
ღილაკი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="266"/>
        <source>Flat buttons</source>
        <translation>ბრტყელი ღილაკები</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="279"/>
        <source>Button Box</source>
        <translation>ღილაკის ველი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="374"/>
        <source>Tool buttons</source>
        <translation>ხელსაწყოს ღილაკები</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="382"/>
        <location filename="../../KvantumPreviewBase.ui" line="459"/>
        <source>Simple toolbutton</source>
        <translation>მარტივი ხელსაწყოს ღილაკი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="466"/>
        <location filename="../../KvantumPreviewBase.ui" line="477"/>
        <source>Multi-line
toolbutton</source>
        <translation>მრავალხაზიანი
ხელსაწყოს ღილაკი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="485"/>
        <location filename="../../KvantumPreviewBase.ui" line="508"/>
        <source>Toggle toolbutton
with an arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="573"/>
        <location filename="../../KvantumPreviewBase.ui" line="597"/>
        <source>Toolbutton with 32px SVG icon
and text below</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="618"/>
        <location filename="../../KvantumPreviewBase.ui" line="639"/>
        <source>Toolbutton with text below
and arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="657"/>
        <location filename="../../KvantumPreviewBase.ui" line="678"/>
        <source>Toolbutton with icon at the side
and arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="696"/>
        <location filename="../../KvantumPreviewBase.ui" line="723"/>
        <source>Toggle toolbutton with icon,
ordinary arrow
and dropdown menu arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="528"/>
        <location filename="../../KvantumPreviewBase.ui" line="552"/>
        <source>Toolbutton with 32px PNG icon
beside text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="366"/>
        <source>Push button with menu</source>
        <translation>დასაჭერი ღილაკი მენიუთი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="415"/>
        <source>Toggle
tool
button

with
height
greater
than
width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="804"/>
        <source>Auto-raise</source>
        <translation>ავტოამოწევა</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="825"/>
        <source>Radio/Check buttons</source>
        <translation>გადასართავი/ჩასართავი ღილაკები</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="846"/>
        <location filename="../../KvantumPreviewBase.ui" line="859"/>
        <source>Simple radio button</source>
        <translation>უბრალო გადამრთველი ღილაკი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="869"/>
        <location filename="../../KvantumPreviewBase.ui" line="880"/>
        <source>Multi-line
radio button</source>
        <translation>მრავალხაზიანი
გადამრთველი ღილაკი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="891"/>
        <location filename="../../KvantumPreviewBase.ui" line="917"/>
        <source>Radio button with 32px SVG icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="940"/>
        <location filename="../../KvantumPreviewBase.ui" line="953"/>
        <source>Simple check box</source>
        <translation>უბრალო თოლია</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="963"/>
        <location filename="../../KvantumPreviewBase.ui" line="974"/>
        <source>Multi-line
check box</source>
        <translation>მრავალხაზიანი
თოლია</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="982"/>
        <location filename="../../KvantumPreviewBase.ui" line="995"/>
        <source>Tri-state check box</source>
        <translation>სამმდგოარეობიანი თოლია</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1005"/>
        <location filename="../../KvantumPreviewBase.ui" line="1019"/>
        <source>Check box with icon</source>
        <translation>თოლია ხატულათი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1075"/>
        <source>Combos/Spins/Inputs</source>
        <translation>სიები/მთვლელები/შეყვანისველები</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1188"/>
        <location filename="../../KvantumPreviewBase.ui" line="1261"/>
        <location filename="../../KvantumPreviewBase.ui" line="1423"/>
        <location filename="../../KvantumPreviewBase.ui" line="1505"/>
        <location filename="../../KvantumPreviewBase.ui" line="1594"/>
        <location filename="../../KvantumPreviewBase.ui" line="1607"/>
        <source>Frameless (no difference)</source>
        <translation>უჩარჩოო (სხვაობის გარეშე)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1110"/>
        <location filename="../../KvantumPreviewBase.ui" line="1149"/>
        <source>Standard combo box</source>
        <translation>სტანდარტული ველი სიით</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1119"/>
        <location filename="../../KvantumPreviewBase.ui" line="1158"/>
        <source>Standard combo box 1</source>
        <translation>სტანდარტული ჩამოსაშლელი სია 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1127"/>
        <location filename="../../KvantumPreviewBase.ui" line="1166"/>
        <source>Standard combo box 2</source>
        <translation>სტანდარტული ჩამოსაშლელი სია 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1132"/>
        <location filename="../../KvantumPreviewBase.ui" line="1171"/>
        <source>Standard combo box 3</source>
        <translation>სტანდარტული ჩამოსაშლელი სია 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1137"/>
        <location filename="../../KvantumPreviewBase.ui" line="1176"/>
        <source>Standard combo box 4</source>
        <translation>სტანდარტული ჩამოსაშლელი სია 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1197"/>
        <location filename="../../KvantumPreviewBase.ui" line="1270"/>
        <location filename="../../KvantumPreviewBase.ui" line="1432"/>
        <location filename="../../KvantumPreviewBase.ui" line="1514"/>
        <source>Frameless 1</source>
        <translation>ჩარჩოს გარეშე 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1206"/>
        <location filename="../../KvantumPreviewBase.ui" line="1279"/>
        <location filename="../../KvantumPreviewBase.ui" line="1441"/>
        <location filename="../../KvantumPreviewBase.ui" line="1523"/>
        <source>Frameless 2</source>
        <translation>ჩარჩოს გარეშე 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1211"/>
        <location filename="../../KvantumPreviewBase.ui" line="1284"/>
        <location filename="../../KvantumPreviewBase.ui" line="1446"/>
        <location filename="../../KvantumPreviewBase.ui" line="1528"/>
        <source>Frameless 3</source>
        <translation>ჩარჩოს გარეშე 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1216"/>
        <location filename="../../KvantumPreviewBase.ui" line="1289"/>
        <location filename="../../KvantumPreviewBase.ui" line="1451"/>
        <location filename="../../KvantumPreviewBase.ui" line="1533"/>
        <source>Frameless 4</source>
        <translation>ჩარჩოს გარეშე 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1221"/>
        <location filename="../../KvantumPreviewBase.ui" line="1294"/>
        <location filename="../../KvantumPreviewBase.ui" line="1456"/>
        <location filename="../../KvantumPreviewBase.ui" line="1538"/>
        <source>Frameless 5</source>
        <translation>ჩარჩოს გარეშე 5</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1226"/>
        <location filename="../../KvantumPreviewBase.ui" line="1299"/>
        <location filename="../../KvantumPreviewBase.ui" line="1461"/>
        <location filename="../../KvantumPreviewBase.ui" line="1543"/>
        <source>Frameless 6</source>
        <translation>ჩარჩოს გარეშე 6</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1231"/>
        <location filename="../../KvantumPreviewBase.ui" line="1304"/>
        <location filename="../../KvantumPreviewBase.ui" line="1466"/>
        <location filename="../../KvantumPreviewBase.ui" line="1548"/>
        <source>Frameless 7</source>
        <translation>ჩარჩოს გარეშე 7</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1236"/>
        <location filename="../../KvantumPreviewBase.ui" line="1309"/>
        <location filename="../../KvantumPreviewBase.ui" line="1471"/>
        <location filename="../../KvantumPreviewBase.ui" line="1553"/>
        <source>Frameless 8</source>
        <translation>ჩარჩოს გარეშე 8</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1241"/>
        <location filename="../../KvantumPreviewBase.ui" line="1314"/>
        <location filename="../../KvantumPreviewBase.ui" line="1476"/>
        <location filename="../../KvantumPreviewBase.ui" line="1558"/>
        <source>Frameless 9</source>
        <translation>ჩარჩოს გარეშე 9</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1246"/>
        <location filename="../../KvantumPreviewBase.ui" line="1319"/>
        <location filename="../../KvantumPreviewBase.ui" line="1481"/>
        <location filename="../../KvantumPreviewBase.ui" line="1563"/>
        <source>Frameless 10</source>
        <translation>ჩარჩოს გარეშე 10</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1331"/>
        <location filename="../../KvantumPreviewBase.ui" line="1374"/>
        <source>Editable combo box</source>
        <translation>ჩასწორებადი სიის ველი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1340"/>
        <location filename="../../KvantumPreviewBase.ui" line="1383"/>
        <source>Editable combo box 1</source>
        <translation>ჩასწორებადი ჩამოსაშლელი სია 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1349"/>
        <location filename="../../KvantumPreviewBase.ui" line="1392"/>
        <source>Editable combo box 2</source>
        <translation>ჩასწორებადი ჩამოსაშლელი სია 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1354"/>
        <location filename="../../KvantumPreviewBase.ui" line="1397"/>
        <source>Editable combo box 3</source>
        <translation>ჩასწორებადი ჩამოსაშლელი სია 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1359"/>
        <location filename="../../KvantumPreviewBase.ui" line="1402"/>
        <source>Editable combo box 4</source>
        <translation>ჩასწორებადი ჩამოსაშლელი სია 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1571"/>
        <location filename="../../KvantumPreviewBase.ui" line="1584"/>
        <source>Line-edit</source>
        <translation>შეყვანის სტრიქონი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1673"/>
        <source>Sliders/Scrolls/Progress/Dial</source>
        <translation>სლაიდერები/ჩოჩია/მიმდინარეობა/დარეკვა</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2230"/>
        <source>Containers</source>
        <translation>კონტეინერები</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2251"/>
        <source>Header 1</source>
        <translation>თავსართი 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2260"/>
        <source>Header 2</source>
        <translation>თავსართი 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2268"/>
        <source>Header 3</source>
        <translation>თავსართი 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2273"/>
        <location filename="../../KvantumPreviewBase.ui" line="2371"/>
        <source>3rd Item</source>
        <translation>მესამე ელემენტი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2281"/>
        <location filename="../../KvantumPreviewBase.ui" line="2359"/>
        <source>2nd Item</source>
        <translation>მეორე ელემენტი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2285"/>
        <location filename="../../KvantumPreviewBase.ui" line="2321"/>
        <source>2nd Child</source>
        <translation>მეორე შვილი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2290"/>
        <location filename="../../KvantumPreviewBase.ui" line="2326"/>
        <source>1st Child</source>
        <translation>პირველი შვილი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2296"/>
        <location filename="../../KvantumPreviewBase.ui" line="2344"/>
        <source>1st Item</source>
        <translation>პირველი ელემენტი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2316"/>
        <source>3rd Child</source>
        <translation>მესამე შვილი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2614"/>
        <source>Row 0</source>
        <translation>მწკრივი 0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2619"/>
        <source>Row 1</source>
        <translation>მწკრივი 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2624"/>
        <source>Column 0</source>
        <translation>სვეტი 0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2632"/>
        <source>Column 1</source>
        <translation>სვეტი 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2637"/>
        <source>0-0</source>
        <translation>0-0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2645"/>
        <source>0-1</source>
        <translation>0-1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2653"/>
        <source>1-0</source>
        <translation>1-0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2661"/>
        <source>1-1</source>
        <translation>1-1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2303"/>
        <location filename="../../KvantumPreviewBase.ui" line="2306"/>
        <source>Editable</source>
        <translation>ჩასწორებადი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2333"/>
        <source>Non-Editable</source>
        <translation>არაჩასწორებადი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2381"/>
        <source>Subwindow</source>
        <translation>ქვეფანჯარა</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2428"/>
        <source>Panel frame</source>
        <translation>პანელის ჩარჩო</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2447"/>
        <location filename="../../KvantumPreviewBase.ui" line="2588"/>
        <location filename="../../KvantumPreviewBase.ui" line="2680"/>
        <source>GroupBox</source>
        <translation>GroupBox</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2467"/>
        <location filename="../../KvantumPreviewBase.ui" line="2519"/>
        <location filename="../../KvantumPreviewBase.ui" line="2813"/>
        <location filename="../../KvantumPreviewBase.ui" line="2890"/>
        <location filename="../../KvantumPreviewBase.ui" line="2938"/>
        <source>Tab 1</source>
        <translation>ჩანართი 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2473"/>
        <source>Page 1 (disabled)</source>
        <translation>გვერდი 1 (გამორთულია)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2485"/>
        <location filename="../../KvantumPreviewBase.ui" line="2533"/>
        <location filename="../../KvantumPreviewBase.ui" line="2831"/>
        <location filename="../../KvantumPreviewBase.ui" line="2904"/>
        <location filename="../../KvantumPreviewBase.ui" line="2952"/>
        <source>Tab 2</source>
        <translation>ჩანართი 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2491"/>
        <source>Page 2 (disabled)</source>
        <translation>გვერდი 2 (გამორთულია)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2525"/>
        <location filename="../../KvantumPreviewBase.ui" line="2718"/>
        <location filename="../../KvantumPreviewBase.ui" line="2773"/>
        <location filename="../../KvantumPreviewBase.ui" line="2896"/>
        <location filename="../../KvantumPreviewBase.ui" line="2944"/>
        <source>Page 1</source>
        <translation>გვერდი 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2539"/>
        <location filename="../../KvantumPreviewBase.ui" line="2746"/>
        <location filename="../../KvantumPreviewBase.ui" line="2786"/>
        <location filename="../../KvantumPreviewBase.ui" line="2837"/>
        <location filename="../../KvantumPreviewBase.ui" line="2910"/>
        <location filename="../../KvantumPreviewBase.ui" line="2958"/>
        <source>Page 2</source>
        <translation>გვერდი 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2563"/>
        <source>Stack widget (page1)</source>
        <translation>სტეკის ვიჯეტი (გვერდი1)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2577"/>
        <source>Stack Widget (page2)</source>
        <translation>სტეკის ვიჯეტი (გვერდი2)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2594"/>
        <source>Group box</source>
        <translation>ჯგუფის ველი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2672"/>
        <source>Dock Widget</source>
        <translation>მიმაგრებადი ვიჯეტი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2689"/>
        <source>Checkable group box</source>
        <translation>ჩართვადი ჯგუფური ველი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2724"/>
        <source>Tool Box</source>
        <translation>ინსტრუმენტები</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2819"/>
        <source>Document mode</source>
        <translation>დოკუმენტის რეჟიმი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2857"/>
        <source>Box frame</source>
        <translation>ველის ჩარჩო</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2987"/>
        <source>&amp;File</source>
        <translation>&amp;ფაილი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2991"/>
        <source>&amp;Submenu</source>
        <translation>&amp;ქვემენიუ</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3011"/>
        <source>toolBar</source>
        <translation>ხელსაწყოთა ზოლი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3031"/>
        <source>toolBar_2</source>
        <translation>toolBar_2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3053"/>
        <source>&amp;Quit</source>
        <translation>გამოსვლა</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3056"/>
        <source>Quit</source>
        <translation>გასვლა</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3059"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3067"/>
        <source>&amp;Checkbox</source>
        <translation>თო&amp;ლია</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3080"/>
        <source>Toggle Layout</source>
        <translation>განლაგების გადართვა</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3083"/>
        <source>Toggle layout direction</source>
        <translation>განლაგების მიმართულების გადართვა</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3095"/>
        <source>&amp;Doc Mode</source>
        <translation>მიმაგრების რე&amp;ჟიმი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3098"/>
        <source>Show tabs in the document mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3110"/>
        <source>Menu Button</source>
        <translation>მენიუს ღილაკი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3113"/>
        <source>Hold pressed to show a menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3124"/>
        <source>C&amp;heckbox</source>
        <translation>თ&amp;ოლია</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3132"/>
        <source>&amp;Radio button</source>
        <translation>&amp;რადიო ღილაკი</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3140"/>
        <source>Radio &amp;button</source>
        <translation>&amp;რადიო ღილაკი</translation>
    </message>
</context>
</TS>
